@@ -377,7 +377,7 @@ impl TryFrom<protobuf::UpdatePlaylist> for UpdatePlaylistEvents {
     }
 }
 
-/// Easily unwrap a given grpc option and covert it to a result, with a location on None
+/// Easily unwrap a given grpc option and convert it to a result, with a location on None
 fn unwrap_msg<T>(opt: Option<T>, place: &str) -> Result<T, anyhow::Error> {
     match opt {
         Some(val) => Ok(val),
@@ -385,8 +385,12 @@ fn unwrap_msg<T>(opt: Option<T>, place: &str) -> Result<T, anyhow::Error> {
     }
 }
 
+/// Clamp a given `u32` to be `u16`.
+///
+/// This is mainly used for volume clamping as we only use u16 for that, but protobuf minimal number is u32.
 #[allow(clippy::cast_possible_truncation)]
-fn clamp_u16(val: u32) -> u16 {
+#[must_use]
+pub fn clamp_u16(val: u32) -> u16 {
     val.min(u32::from(u16::MAX)) as u16
 }
 
