@@ -102,9 +102,24 @@ pub enum PlayerErrorType {
 
 #[derive(Clone, Debug)]
 pub enum PlayerCmd {
+    // Mainly called from the backends
+    /// The Backend indicates the current track is about to end.
     AboutToFinish,
-    CycleLoop,
+    /// The Backend indicates that the current track has ended.
     Eos,
+    /// The Backend indicates new metadata is available.
+    MetadataChanged,
+    /// A Error happened in the backend (for example `NotFound`) that makes it unrecoverable to continue to play the current track.
+    /// This will basically be treated as a [`Eos`](PlayerCmd::Eos), with some extra handling.
+    ///
+    /// This should **not** be used if the whole backend is unrecoverable.
+    Error(PlayerErrorType),
+
+    // Internal only
+    Tick,
+
+    // Mainly called from outside sources (client, mpris)
+    CycleLoop,
     GetProgress,
     SkipPrevious,
     Pause,
@@ -117,16 +132,11 @@ pub enum PlayerCmd {
     SkipNext,
     SpeedDown,
     SpeedUp,
-    Tick,
     ToggleGapless,
     TogglePause,
     VolumeDown,
     VolumeUp,
-    /// A Error happened in the backend (for example `NotFound`) that makes it unrecoverable to continue to play the current track.
-    /// This will basically be treated as a [`Eos`](PlayerCmd::Eos), with some extra handling.
-    ///
-    /// This should **not** be used if the whole backend is unrecoverable.
-    Error(PlayerErrorType),
+    VolumeSet(Volume),
 
     PlaylistPlaySpecific(PlaylistPlaySpecific),
     PlaylistAddTrack(PlaylistAddTrack),
@@ -348,6 +358,11 @@ impl GeneralPlayer {
         }
     }
 
+    /// Handle [`PlayerCmd::MetadataChanged`] for all things the [`GeneralPlayer`] controls.
+    pub fn metadata_changed(&mut self) {
+        self.send_track_changed();
+    }
+
     /// Send event [`UpdateEvents::TrackChanged`]. In a function to de-duplicate calls.
     fn send_track_changed(&mut self) {
         self.send_stream_ev(UpdateEvents::TrackChanged(TrackChangedInfo {
@@ -613,12 +628,14 @@ impl PlayerTrait for GeneralPlayer {
     }
     fn add_volume(&mut self, volume: VolumeSigned) -> Volume {
         let vol = self.get_player_mut().add_volume(volume);
+        self.mpris_volume_update();
         self.send_stream_ev(UpdateEvents::VolumeChanged { volume: vol });
 
         vol
     }
     fn set_volume(&mut self, volume: Volume) -> Volume {
         let vol = self.get_player_mut().set_volume(volume);
+        self.mpris_volume_update();
         self.send_stream_ev(UpdateEvents::VolumeChanged { volume: vol });
 
         vol
