@@ -2,6 +2,7 @@ use std::borrow::Cow;
 use std::path::Path;
 use std::time::Duration;
 
+use anyhow::Result;
 use either::Either;
 use termusiclib::common::const_unknown::{UNKNOWN_ARTIST, UNKNOWN_FILE, UNKNOWN_TITLE};
 use termusiclib::config::SharedTuiSettings;
@@ -591,7 +592,8 @@ impl Matchable for &track_ops::TrackRead {
 }
 
 impl Model {
-    pub fn database_sync_tracks(&mut self) {
+    /// Build & Apply the `Tracks` Database component table data.
+    pub fn database_sync_tracks_results(&mut self) {
         let mut table: TableBuilder = TableBuilder::default();
 
         for (idx, record) in self.dw.search_tracks.iter().enumerate() {
@@ -624,30 +626,27 @@ impl Model {
 
         // self.playlist_update_title();
     }
+
+    /// Build & Apply the `Results` Database component table data.
     pub fn database_sync_results(&mut self) {
         let mut table: TableBuilder = TableBuilder::default();
-        let mut index = 0;
         for (idx, record) in self.dw.search_results.iter().enumerate() {
             let mut display_name = String::new();
             match self.dw.criteria {
                 SearchCriteria::Playlist => {
                     let path = Path::new(record);
-                    let path_string = path.to_string_lossy().to_string();
-                    let mut vec = path_string.split('/');
-                    if let Some(v1) = vec.next_back() {
-                        if let Some(v2) = vec.next_back() {
-                            display_name = format!("{v2}/{v1}");
-                        }
+                    let path_str = path.to_string_lossy();
+                    let mut vec = path_str.split('/').rev();
+                    if let (Some(v1), Some(v2)) = (vec.next(), vec.next()) {
+                        display_name = format!("{v2}/{v1}");
                     }
                 }
                 SearchCriteria::Directory => {
                     let path = Path::new(record);
-                    let path_string = path.to_string_lossy().to_string();
-                    let mut vec = path_string.split('/');
-                    if let Some(v1) = vec.next_back() {
-                        if let Some(v2) = vec.next_back() {
-                            display_name = format!("{v2}/{v1}/");
-                        }
+                    let path_string = path.to_string_lossy();
+                    let mut vec = path_string.split('/').rev();
+                    if let (Some(v1), Some(v2)) = (vec.next(), vec.next()) {
+                        display_name = format!("{v2}/{v1}/");
                     }
                 }
                 _ => {
@@ -658,9 +657,8 @@ impl Model {
                 if idx > 0 {
                     table.add_row();
                 }
-                index += 1;
                 table
-                    .add_col(TextSpan::from(format!("{index}")))
+                    .add_col(TextSpan::from(format!("{}", idx + 1)))
                     .add_col(TextSpan::from(" "))
                     .add_col(TextSpan::from(display_name));
             }
@@ -736,20 +734,24 @@ impl Model {
         self.app.active(&Id::DBListSearchResult).ok();
     }
 
+    /// Scan all Music Roots for all playlists.
     fn database_get_playlist(&self) -> Vec<String> {
         let mut vec = Vec::new();
 
-        let root = self.library.tree.root();
-        let p: &Path = Path::new(root.id());
-        let all_items = walkdir::WalkDir::new(p).follow_links(true);
-        for record in all_items
-            .into_iter()
-            .filter_map(std::result::Result::ok)
-            .filter(|p| is_playlist(p.path()))
-        {
-            let full_path_name = record.path().to_string_lossy().to_string();
-            vec.push(full_path_name);
+        for dir in &self.config_server.read().settings.player.music_dirs {
+            let absolute_dir = shellexpand::path::tilde(dir);
+
+            let all_items = walkdir::WalkDir::new(absolute_dir).follow_links(true);
+            for record in all_items
+                .into_iter()
+                .filter_map(std::result::Result::ok)
+                .filter(|p| is_playlist(p.path()))
+            {
+                let full_path_name = record.path().to_string_lossy().to_string();
+                vec.push(full_path_name);
+            }
         }
+
         vec
     }
 
@@ -890,7 +892,7 @@ impl Model {
 
         self.dw.search_tracks = result;
 
-        self.database_sync_tracks();
+        self.database_sync_tracks_results();
         self.app.active(&Id::DBListSearchTracks).ok();
     }
 
@@ -913,50 +915,46 @@ impl Model {
         }
     }
 
-    pub fn database_reload(&mut self) {
-        assert!(
-            self.app
-                .remount(
-                    Id::DBListCriteria,
-                    Box::new(DBListCriteria::new(
-                        self.config_tui.clone(),
-                        Msg::DataBase(DBMsg::CriteriaBlurDown),
-                        Msg::DataBase(DBMsg::CriteriaBlurUp)
-                    )),
-                    Vec::new()
-                )
-                .is_ok()
-        );
+    /// Mount/Remount the Database search result components.
+    pub fn remount_database_search(&mut self) -> Result<()> {
+        self.app.remount(
+            Id::DBListCriteria,
+            Box::new(DBListCriteria::new(
+                self.config_tui.clone(),
+                Msg::DataBase(DBMsg::CriteriaBlurDown),
+                Msg::DataBase(DBMsg::CriteriaBlurUp),
+            )),
+            Vec::new(),
+        )?;
 
-        assert!(
-            self.app
-                .remount(
-                    Id::DBListSearchResult,
-                    Box::new(DBListSearchResult::new(
-                        self.config_tui.clone(),
-                        Msg::DataBase(DBMsg::SearchResultBlurDown),
-                        Msg::DataBase(DBMsg::SearchResultBlurUp)
-                    )),
-                    Vec::new()
-                )
-                .is_ok()
-        );
-        assert!(
-            self.app
-                .remount(
-                    Id::DBListSearchTracks,
-                    Box::new(DBListSearchTracks::new(
-                        self.config_tui.clone(),
-                        Msg::DataBase(DBMsg::SearchTracksBlurDown),
-                        Msg::DataBase(DBMsg::SearchTracksBlurUp)
-                    )),
-                    Vec::new()
-                )
-                .is_ok()
-        );
+        self.app.remount(
+            Id::DBListSearchResult,
+            Box::new(DBListSearchResult::new(
+                self.config_tui.clone(),
+                Msg::DataBase(DBMsg::SearchResultBlurDown),
+                Msg::DataBase(DBMsg::SearchResultBlurUp),
+            )),
+            Vec::new(),
+        )?;
+        self.app.remount(
+            Id::DBListSearchTracks,
+            Box::new(DBListSearchTracks::new(
+                self.config_tui.clone(),
+                Msg::DataBase(DBMsg::SearchTracksBlurDown),
+                Msg::DataBase(DBMsg::SearchTracksBlurUp),
+            )),
+            Vec::new(),
+        )?;
+
+        Ok(())
+    }
+
+    /// Reload database component data.
+    pub fn database_reload(&mut self) {
+        self.remount_database_search().unwrap();
 
         self.dw.reset_search_results();
-        self.database_sync_tracks();
+        self.database_sync_tracks_results();
         self.database_sync_results();
     }
 
