@@ -24,12 +24,10 @@ mod xywh;
 
 // -- export
 pub use config_editor::*;
-pub use database::{DBListCriteria, DBListSearchResult, DBListSearchTracks};
+pub use database::DBListCriteria;
 pub use footer::Footer;
-pub use global_listener::GlobalListener;
 pub use labels::{DownloadSpinner, LabelGeneric, LabelSpan};
 pub use lyric::Lyric;
-pub use music_library::MusicLibrary;
 pub use playlist::Playlist;
 pub use podcast::{EpisodeList, FeedsList};
 pub use popups::general_search::{GSInputPopup, GSTablePopup, Source};
