@@ -1,13 +1,13 @@
 use std::borrow::Cow;
 use std::ffi::OsString;
-use std::path::Path;
+use std::path::{Path, PathBuf};
 use std::time::Duration;
 
 use anyhow::{Context as _, Result, anyhow, bail};
 use rand::seq::IndexedRandom;
 use termusiclib::common::const_unknown::{UNKNOWN_ALBUM, UNKNOWN_ARTIST};
 use termusiclib::config::SharedTuiSettings;
-use termusiclib::config::v2::server::LoopMode;
+use termusiclib::config::v2::server::{LoopMode, ScanDepth};
 use termusiclib::new_database::track_ops::TrackRead;
 use termusiclib::new_database::{album_ops, track_ops};
 use termusiclib::player::playlist_helpers::{
@@ -34,9 +34,10 @@ use tuirealm::{
 };
 
 use crate::ui::Model;
+use crate::ui::components::music_library::library_dir_tree;
 use crate::ui::ids::Id;
 use crate::ui::model::{TermusicLayout, UserEvent};
-use crate::ui::msg::{GSMsg, Msg, PLMsg};
+use crate::ui::msg::{GSMsg, Msg, PLMsg, SearchCriteria};
 use crate::ui::tui_cmd::{PlaylistCmd, TuiCmd};
 
 #[derive(MockComponent)]
@@ -324,6 +325,15 @@ impl Model {
         Ok(())
     }
 
+    fn playlist_get_dir_entries(path: &Path) -> Vec<String> {
+        // use the same function as the tree order gets generated in, so that we add in a expected order
+        let vec = library_dir_tree(path, ScanDepth::Limited(1));
+        vec.children
+            .into_iter()
+            .map(|v| v.id.to_string_lossy().to_string())
+            .collect()
+    }
+
     /// Add the `current_node`, regardless if it is a Track, dir, playlist, etc.
     ///
     /// See [`Model::playlist_add_episode`] for podcast episode adding
@@ -332,7 +342,7 @@ impl Model {
             return Ok(());
         }
         if path.is_dir() {
-            let new_items_vec = Self::library_dir_children(path);
+            let new_items_vec = Self::playlist_get_dir_entries(path);
 
             let sources = new_items_vec
                 .into_iter()
@@ -888,15 +898,20 @@ impl Model {
             return Ok(());
         }
 
-        self.playlist_save_m3u(&path_m3u)
+        self.playlist_save_m3u(path_m3u)
     }
 
     /// Save the current playlist as m3u in the given full path
-    pub fn playlist_save_m3u(&mut self, filename: &Path) -> Result<()> {
+    pub fn playlist_save_m3u(&mut self, filename: PathBuf) -> Result<()> {
         // TODO: move this to server?
-        self.playback.playlist.save_m3u(filename)?;
+        self.playback.playlist.save_m3u(&filename)?;
 
-        self.library_reload_with_node_focus(Some(filename.to_string_lossy().to_string()));
+        self.library_reload_and_focus(filename);
+
+        // only reload database results, if the criteria is for playlists
+        if self.dw.criteria == SearchCriteria::Playlist {
+            self.database_update_search_results();
+        }
 
         Ok(())
     }
